@@ -208,6 +208,13 @@ void ElisaApplication::setupActions(const QString &actionName)
         d->mCollection.addAction(findAction->objectName(), findAction);
     }
 
+    if (actionName == QLatin1String("togglePartyMode") && KAuthorized::authorizeAction(actionName)) {
+        auto togglePartyModeAction = d->mCollection.addAction(actionName, this, &ElisaApplication::togglePartyMode);
+        togglePartyModeAction->setText(i18n("Toggle Party Mode"));
+        d->mCollection.setDefaultShortcut(togglePartyModeAction, QKeySequence(Qt::Key_F11));
+        d->mCollection.addAction(togglePartyModeAction->objectName(), togglePartyModeAction);
+    }
+
     d->mCollection.readSettings();
 #endif
 }
@@ -329,6 +336,8 @@ void ElisaApplication::previousTrack() {}
 
 void ElisaApplication::playPause() {}
 
+void ElisaApplication::togglePartyMode() {}
+
 void ElisaApplication::configChanged()
 {
     auto currentConfiguration = Elisa::ElisaConfiguration::self();
@@ -338,6 +347,7 @@ void ElisaApplication::configChanged()
     currentConfiguration->load();
     currentConfiguration->read();
 
+    Q_EMIT showNowPlayingBackgroundChanged();
     Q_EMIT showProgressOnTaskBarChanged();
     Q_EMIT showSystemTrayIconChanged();
     Q_EMIT embeddedViewChanged();
@@ -382,6 +392,12 @@ void ElisaApplication::initialize()
     initializeModels();
     initializePlayer();
 
+#if defined Q_OS_ANDROID
+    QIcon::setThemeName(QStringLiteral("Breeze"));
+    QIcon::setFallbackSearchPaths({QIcon::themeSearchPaths().first() + QStringLiteral("/icons")});
+    QIcon::setThemeSearchPaths({QIcon::themeSearchPaths().first()});
+#endif
+
     Q_EMIT initializationDone();
 }
 
@@ -526,7 +542,7 @@ bool ElisaApplication::eventFilter(QObject *object, QEvent *event)
     Q_UNUSED(object)
 
     auto *keyEvent = static_cast<QKeyEvent*>(event);
-    auto playPauseAction = d->mCollection.action(tr("Play-Pause"));
+    auto playPauseAction = d->mCollection.action(QStringLiteral("Play-Pause"));
     if (keyEvent->key() == Qt::Key_Space && playPauseAction->shortcut()[0] == Qt::Key_Space) {
         return true;
     }
@@ -580,6 +596,13 @@ ManageHeaderBar *ElisaApplication::manageHeaderBar() const
     return d->mManageHeaderBar.get();
 }
 
+
+bool ElisaApplication::showNowPlayingBackground() const
+{
+    auto currentConfiguration = Elisa::ElisaConfiguration::self();
+    return currentConfiguration->showNowPlayingBackground();
+}
+
 bool ElisaApplication::showProgressOnTaskBar() const
 {
     auto currentConfiguration = Elisa::ElisaConfiguration::self();
